@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: IOBlob.pm,v 1.7 2001/10/24 14:40:05 rich Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::DBeg1::IOBlob - The example DB FTP server personality
 
   use Net::FTPServer::DBeg1::IOBlob;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::DBeg1::IOBlob;
@@ -43,11 +37,15 @@ package Net::FTPServer::DBeg1::IOBlob;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.7 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use DBI;
 use Carp qw(confess croak);
 
+=pod
+
+=over 4
+
 =item $io = Net::FTPServer::DBeg1::IOBlob ('r', $dbh, $blob_id);
 
 =item $io = Net::FTPServer::DBeg1::IOBlob ('w', $dbh, $blob_id);
@@ -212,7 +210,7 @@ sub DESTROY
 
 __END__
 
-=back 4
+=back
 
 =head1 AUTHORS
 
@@ -225,6 +223,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
