@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: Server.pm,v 1.5 2001/10/24 14:40:05 rich Exp $
-
 =pod
 
 =head1 NAME
@@ -38,8 +36,6 @@ FTP server with a PostgreSQL database back-end.
 
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::DBeg1::Server;
@@ -47,7 +43,7 @@ package Net::FTPServer::DBeg1::Server;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.5 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use DBI;
 
@@ -177,8 +173,6 @@ sub _SITE_USAGE_command
 
 __END__
 
-=back 4
-
 =head1 FILES
 
   /etc/ftpd.conf
@@ -201,9 +195,9 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>,
-L<Net::FTP(3)>,
-L<perl(1)>,
+C<Net::FTPServer(3)>,
+C<Net::FTP(3)>,
+C<perl(1)>,
 RFC 765,
 RFC 959,
 RFC 1579,
