@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: FileHandle.pm,v 1.1 2003/09/28 11:50:45 rwmj Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::InMem::FileHandle - Store files in local memory
 
   use Net::FTPServer::InMem::FileHandle;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::InMem::FileHandle;
@@ -43,7 +37,7 @@ package Net::FTPServer::InMem::FileHandle;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.2 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use Carp qw(croak confess);
 use IO::Scalar;
@@ -114,7 +108,6 @@ sub open
 sub status
   {
     my $self = shift;
-    my $dbh = $self->{ftps}{fs_dbh};
     my $username = substr $self->{ftps}{user}, 0, 8;
 
     my $size = length $ { $self->{fs_content} };
@@ -153,8 +146,6 @@ sub delete
 
 __END__
 
-=back 4
-
 =head1 AUTHORS
 
 Richard Jones (rich@annexia.org).
@@ -166,6 +157,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
